@@ -7,6 +7,7 @@ from requests import ConnectionError
 from urllib3.connection import ConnectTimeoutError
 
 from ..exceptions.gateway import GatewayOfflineError
+from ..mydevolo import Mydevolo
 from .mprm_rest import MprmRest
 
 
@@ -19,11 +20,13 @@ class MprmWebsocket(MprmRest):
 
     The websocket connection itself runs in a thread, that might not terminate as expected. Using a with-statement is
     recommended.
+
+    :param mydevolo_instance: Mydevolo instance for talking to the devolo Cloud
     """
 
-    def __init__(self):
-        super().__init__()
-        self._ws = None
+    def __init__(self, mydevolo_instance: Mydevolo):
+        super().__init__(mydevolo_instance)
+        self._ws: websocket.WebSocketApp = None
         self._connected = False     # This attribute saves, if the websocket is fully established
         self._reachable = True      # This attribute saves, if the a new session can be established
         self._event_sequence = 0
@@ -83,7 +86,7 @@ class MprmWebsocket(MprmRest):
         Close the websocket connection.
         """
         self._logger.info("Closing web socket connection.")
-        if event != "":
+        if event:
             self._logger.info(f"Reason: {event}")
         self._ws.close()
 
@@ -92,9 +95,9 @@ class MprmWebsocket(MprmRest):
         """ Callback method to react on closing the websocket. """
         self._logger.info("Closed web socket connection.")
 
-    def _on_error(self, error: str):
+    def _on_error(self, error: Exception):
         """ Callback method to react on errors. We will try reconnecting with prolonging intervals. """
-        self._logger.error(error)
+        self._logger.exception(error)
         self._connected = False
         self._reachable = False
         self._ws.close()
