@@ -5,6 +5,7 @@ from requests import Session
 
 from ..devices.gateway import Gateway
 from ..exceptions.device import SwitchingProtected, WrongElementError
+from ..mydevolo import Mydevolo
 from .property import Property
 
 
@@ -14,16 +15,17 @@ class BinarySwitchProperty(Property):
 
     :param gateway: Instance of a Gateway object
     :param session: Instance of a requests.Session object
+    :param mydevolo: Mydevolo instance for talking to the devolo Cloud
     :param element_uid: Element UID, something like devolo.BinarySwitch:hdm:ZWave:CBC56091/24#2
     :key enabled: State of the remote protection setting
     :key state: State the switch has at time of creating this instance
     """
 
-    def __init__(self, gateway: Gateway, session: Session, element_uid: str, **kwargs: Any):
+    def __init__(self, gateway: Gateway, session: Session, mydevolo: Mydevolo, element_uid: str, **kwargs: Any):
         if not element_uid.startswith("devolo.BinarySwitch:"):
             raise WrongElementError(f"{element_uid} is not a Binary Switch.")
 
-        super().__init__(gateway=gateway, session=session, element_uid=element_uid)
+        super().__init__(gateway=gateway, session=session, mydevolo=mydevolo, element_uid=element_uid)
 
         self._state = kwargs.get("state", False)
         self.enabled = kwargs.get("enabled", False)
