@@ -5,6 +5,7 @@ from requests import Session
 from ..backend.mprm_rest import MprmRest
 from ..devices.gateway import Gateway
 from ..devices.zwave import get_device_uid_from_element_uid
+from ..mydevolo import Mydevolo
 
 
 class Property(MprmRest):
@@ -13,10 +14,11 @@ class Property(MprmRest):
 
     :param gateway: Instance of a Gateway object
     :param session: Instance of a requests.Session object
+    :param mydevolo: Mydevolo instance for talking to the devolo Cloud
     :param element_uid: Element UID, something like devolo.BinarySwitch:hdm:ZWave:CBC56091/24#2
     """
 
-    def __init__(self, gateway: Gateway, session: Session, element_uid: str):
+    def __init__(self, gateway: Gateway, session: Session, mydevolo: Mydevolo, element_uid: str):
         self.element_uid = element_uid
         self.device_uid = get_device_uid_from_element_uid(element_uid)
 
@@ -24,7 +26,7 @@ class Property(MprmRest):
         self._gateway = gateway
         self._session = session
 
-        super().__init__()
+        super().__init__(mydevolo_instance=mydevolo)
 
 
     @property
