@@ -4,6 +4,7 @@ from requests import Session
 
 from ..devices.gateway import Gateway
 from ..exceptions.device import WrongElementError
+from ..mydevolo import Mydevolo
 from .property import Property
 
 
@@ -15,16 +16,17 @@ class SettingsProperty(Property):
 
     :param gateway: Instance of a Gateway object
     :param session: Instance of a requests.Session object
+    :param mydevolo: Mydevolo instance for talking to the devolo Cloud
     :param element_uid: Element UID, something like devolo.BinarySwitch:hdm:ZWave:CBC56091/24#2
     :param **kwargs: Any setting, that shall be available in this object
     """
 
-    def __init__(self, gateway: Gateway, session: Session, element_uid: str, **kwargs: Any):
+    def __init__(self, gateway: Gateway, session: Session, mydevolo: Mydevolo, element_uid: str, **kwargs: Any):
         if not element_uid.startswith(("acs", "bas", "bss", "cps", "gds", "lis", "mas",
                                        "mss", "ps", "sts", "stmss", "trs", "vfs")):
             raise WrongElementError()
 
-        super().__init__(gateway=gateway, session=session, element_uid=element_uid)
+        super().__init__(gateway=gateway, session=session, mydevolo=mydevolo, element_uid=element_uid)
         for key, value in kwargs.items():
             setattr(self, key, value)
 
