@@ -1,8 +1,7 @@
-from typing import Callable
+from typing import Callable, Dict
 import logging
 
 
-
 class Publisher:
     """
     The Publisher send messages to attached subscribers.
@@ -10,9 +9,17 @@ class Publisher:
 
     def __init__(self, events: list):
         self._logger = logging.getLogger(self.__class__.__name__)
-        self._events = {event: dict() for event in events}
+        self._events: Dict = {event: dict() for event in events}
 
 
+    def add_event(self, event: str):
+        """ Add a new event to listen to. """
+        self._events[event] = {}
+
+    def delete_event(self, event: str):
+        """ Delete a not longer needed event. """
+        self._events.pop(event)
+
     def dispatch(self, event: str, message: tuple):
         """ Dispatch the message to the subscribers. """
         for callback in self._get_subscribers_for_specific_event(event).values():
